@@ -22,3 +22,8 @@ def get_app():
 def main():
     app = get_app()
     app()
+
+
+if __name__ == "__main__":
+    pass
+    # a = get_app()(asdf)
