@@ -8,11 +8,14 @@ from typing import Annotated, Optional
 import typer
 from machineconfig.utils.path_extended import PathExtended
 from machineconfig.utils.accessories import randstr
+import json
+# import shutil
 
 from machineconfig.utils.options import choose_from_options
-# from machineconfig.utils.ve import get_ve_activate_line
 from rich.console import Console
 from rich.panel import Panel
+# from machineconfig.utils.ve import get_ve_path_and_ipython_profile
+# from pathlib import Path
 # from rich.text import Text
 
 console = Console()
@@ -61,14 +64,15 @@ except Exception as e:
 """
 
 
-
 def croshell(
-    path: Annotated[Optional[str], typer.Argument(help="read a file.")] = "",
+    path: Annotated[Optional[str], typer.Argument(help="path of file to read.")] = "",
     python: Annotated[bool, typer.Option("--python", "-p", help="flag to use python over IPython.")] = False,
     profile: Annotated[Optional[str], typer.Option("--profile", "-P", help="ipython profile to use, defaults to default profile.")] = None,
     jupyter: Annotated[bool, typer.Option("--jupyter", "-j", help="run in jupyter interactive console")] = False,
+    vscode: Annotated[bool, typer.Option("--vscode", "-c", help="open the script in vscode")] = False,
     streamlit_viewer: Annotated[bool, typer.Option("--stViewer", "-s", help="view in streamlit app")] = False,
     visidata: Annotated[bool, typer.Option("--visidata", "-V", help="open data file in visidata")] = False,
+    marimo: Annotated[bool, typer.Option("--marimo", "-m", help="open the notebook using marimo if available")] = False,
     local: Annotated[bool, typer.Option("--local", "-l", help="run in local mode, not in virtual env.")]= False,
 ) -> None:
     # ==================================================================================
@@ -104,7 +108,6 @@ def croshell(
         program = get_read_data_pycode(str(file_obj))
         text = f"📄 Reading data from: {file_obj.name}"
         console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
-
     else:  # if nothing is specified, then run in interactive mode.
         text = "⌨️  Entering interactive mode"
         console.print(Panel(text, title="[bold blue]Info[/bold blue]"))
@@ -124,7 +127,7 @@ from pathlib import Path
 
 """
 
-    pyfile = PathExtended.tmp().joinpath(f"tmp_scripts/python/croshell/{randstr()}.py")
+    pyfile = PathExtended.tmp().joinpath(f"tmp_scripts/python/croshell/{randstr()}/script.py")
     pyfile.parent.mkdir(parents=True, exist_ok=True)
 
     title = "Reading Data"
@@ -134,10 +137,49 @@ from pathlib import Path
     ipython_profile = ipython_profile if ipython_profile is not None else "default"
     # ve_activateion_line = get_ve_activate_line(ve_name=args.ve or ve_profile_suggested, a_path=str(PathExtended.cwd()))
 
+    # prepare notebook target path (avoid relying on locals())
+    nb_target = pyfile.with_suffix(".ipynb")
+    if jupyter:
+        try:
+            nb_path = pyfile.with_suffix(".ipynb")
+            nb_content = {
+                "cells": [
+                    {
+                        "cell_type": "code",
+                        "metadata": {"language": "python"},
+                        "source": [python_program],
+                        "outputs": [],
+                        "execution_count": None,
+                    }
+                ],
+                "metadata": {},
+                "nbformat": 4,
+                "nbformat_minor": 5,
+            }
+            nb_path.write_text(json.dumps(nb_content), encoding="utf-8")
+            nb_target = nb_path
+        except Exception:
+            # if writing fails, fall back to the default nb_target already set
+            pass
     if visidata:
         fire_line = f"uv run --with visidata,pyarrow vd {str(file_obj)}"
+    elif marimo:
+        fire_line = f"""
+cd {str(pyfile.parent)}
+uv run --with marimo marimo convert {pyfile.name} -o marimo_nb.py
+uv run --with "marimo,machineconfig[plot]>=6.36" marimo edit --host 0.0.0.0 marimo_nb.py
+"""
     elif jupyter:
-        fire_line = f"code --new-window {str(pyfile)}"
+        fire_line = f"uv run --with 'machineconfig[plot]>=6.36' jupyter-lab {str(nb_target)}"
+    elif vscode:
+        fire_line = f"""
+cd {str(pyfile.parent)}
+uv init --python 3.14
+uv venv
+uv add "machineconfig[plot]>=6.36"
+# code serve-web
+code --new-window {str(pyfile)}
+"""
     else:
         if interpreter == "ipython": profile = f" --profile {ipython_profile} --no-banner"
         else: profile = ""
@@ -149,8 +191,10 @@ from pathlib import Path
             else:
                 console.print(Panel("❌ Could not determine the local machineconfig repo root. Please ensure the `REPO_ROOT` in `source_of_truth.py` is correctly set to the local path of the machineconfig repo, or do not use the `--local` flag.", title="Error", border_style="red"))
                 return
-        else: ve_line = """--with "machineconfig[plot]>=5.87" """
-        fire_line = f"uv run --python 3.14 {ve_line} {interpreter} {interactivity} {profile} {str(pyfile)}"
+        else: ve_line = """--with "machineconfig[plot]>=6.36" """
+        # ve_path_maybe, ipython_profile_maybe = get_ve_path_and_ipython_profile(Path.cwd())
+        # --python 3.14
+        fire_line = f"uv run {ve_line} {interpreter} {interactivity} {profile} {str(pyfile)}"
 
     from machineconfig.utils.code import run_shell_script
     run_shell_script(fire_line, clean_env=False)
@@ -161,4 +205,9 @@ def main() -> None:
 
 
 if __name__ == "__main__":
+    # def func(flag: Annotated[bool, typer.Option("--flag/-nf", help="dummy flag for debugging", flag_value=False, is_flag=True)]=True):
+    #     console.print(f"flag: {flag}")
+    # app = typer.Typer()
+    # app.command()(func)
+    # app()
     main()
