@@ -12,11 +12,10 @@ CONFIG_ROOT="$HOME/.config/machineconfig"
 
 # 📂 Add directories to PATH
 add_to_path_if_not_already \
-    "$HOME/.local/bin" \
-    "$HOME/.cargo/bin" \
     "$CONFIG_ROOT/scripts/linux" \
     "$HOME/dotfiles/scripts/linux" \
-
+    "$HOME/.local/bin" \
+    "$HOME/.cargo/bin" \
     "/usr/games"
 # this way, if the script was run multiple times, e.g. due to nested shells in zellij, there will be no duplicates in the path
 # export DISPLAY=localhost:0.0  # xming server
@@ -27,17 +26,21 @@ add_to_path_if_not_already \
 . $CONFIG_ROOT/settings/broot/br.sh
 . $CONFIG_ROOT/settings/lf/linux/exe/lfcd.sh
 . $CONFIG_ROOT/settings/tere/terecd.sh
+# check if file in ~/dotfiles/machineconfig/init_linux.sh exists and source it
+if [ -f "$HOME/dotfiles/machineconfig/init_linux.sh" ]; then
+    # echo "Sourcing $HOME/dotfiles/machineconfig/init_linux.sh"
+    source "$HOME/dotfiles/machineconfig/init_linux.sh"
+fi
 
 # set alias l to lsd -la
 alias l='lsd -la'
-
 alias d=devops
 alias c=cloud
 alias a=agents
 alias s=sessions
 alias ff=ftpx
 alias f=fire
-alias cs=croshell
+alias r=croshell
 
 # alias gcs='gh copilot suggest -t shell'
 # alias gcg='gh copilot suggest -t git'
@@ -58,20 +61,16 @@ alias cs=croshell
 # [ -s "$NVM_DIR/bash_completion" ] && \. "$NVM_DIR/bash_completion"  # This loads nvm bash_completion
 
 
+# https://github.com/atuinsh/atuin
+# eval "$(atuin init bash)"
+
 # source /home/alex/.config/broot/launcher/bash/br
 # eval "$(thefuck --alias)"
 # from https://github.com/ajeetdsouza/zoxide
 eval "$(zoxide init bash)"
 # from https://github.com/starship/starship
 eval "$(starship init bash)"
-# https://github.com/atuinsh/atuin
-# eval "$(atuin init bash)"
 # LEVE THIS IN THE END TO AVOID EXECUTION FAILURE OF THE REST OF THE SCRIPT
 # from https://github.com/cantino/mcfly
 eval "$(mcfly init bash)"
 
-# check if file in ~/dotfiles/machineconfig/init_linux.sh exists and source it
-if [ -f "$HOME/dotfiles/machineconfig/init_linux.sh" ]; then
-    # echo "Sourcing $HOME/dotfiles/machineconfig/init_linux.sh"
-    source "$HOME/dotfiles/machineconfig/init_linux.sh"
-fi
