@@ -1,6 +1,5 @@
-
 from pathlib import Path
-from typing import Callable, Optional, Union, Any, TypeVar, Protocol, List, Generic
+from typing import Callable, Optional, Union, Any, Protocol, List, TypeVar
 import logging
 import time
 from datetime import datetime, timezone, timedelta
@@ -144,24 +143,79 @@ class Scheduler:
         raise ex
 
 
-T = TypeVar("T")
+# T = TypeVar("T")
 T2 = TypeVar("T2")
-
-
 def to_pickle(obj: Any, path: Path) -> None:
     import pickle
-
     path.parent.mkdir(parents=True, exist_ok=True)
     path.write_bytes(pickle.dumps(obj))
 
 
-class Cache(Generic[T]):  # This class helps to accelrate access to latest data coming from expensive function. The class has two flavours, memory-based and disk-based variants."""
+class CacheMemory[T]():
     def __init__(
-        self, source_func: Callable[[], T], expire: timedelta, logger: LoggerTemplate, path: Optional[Path] = None, saver: Callable[[T, Path], Any] = to_pickle, reader: Callable[[Path], T] = from_pickle, name: Optional[str] = None
+        self, source_func: Callable[[], T], expire: timedelta, logger: LoggerTemplate, name: Optional[str] = None
+    ) -> None:
+        self.cache: T
+        self.source_func = source_func
+        self.time_produced = datetime.now()
+        self.logger = logger
+        self.expire = expire
+        self.name = name if isinstance(name, str) else str(self.source_func)
+        self.last_call_is_fresh = False
+
+    @property
+    def age(self) -> timedelta:
+        return datetime.now() - self.time_produced
+
+    def __call__(self, fresh: bool = False) -> T:
+        self.last_call_is_fresh = False
+        if fresh or not hasattr(self, "cache"):
+            if self.logger:
+                why = "There was an explicit fresh order." if fresh else "Previous cache never existed."
+                self.logger.warning(f"""
+🆕 ════════════════════ NEW CACHE ════════════════════
+🔄 {self.name} cache: Populating fresh cache from source func
+ℹ️  Reason: {why}
+════════════════════════════════════════════════════════""")
+            self.cache = self.source_func()
+            self.last_call_is_fresh = True
+            self.time_produced = datetime.now()
+        else:
+            age = self.age
+            if age > self.expire:
+                if self.logger:
+                    self.logger.warning(f"""
+🔄 ════════════════════ CACHE UPDATE ════════════════════
+⚠️  {self.name} cache: Updating cache from source func
+⏱️  Age = {age} > {self.expire}
+════════════════════════════════════════════════════════""")
+                self.cache = self.source_func()
+                self.last_call_is_fresh = True
+                self.time_produced = datetime.now()
+            else:
+                if self.logger:
+                    self.logger.warning(f"""
+✅ ════════════════════ USING CACHE ════════════════════
+📦 {self.name} cache: Using cached values
+⏱️  Lag = {age}
+════════════════════════════════════════════════════════""")
+        return self.cache
+
+    @staticmethod
+    def as_decorator(expire: timedelta, logger: LoggerTemplate, name: Optional[str] = None):
+        def decorator(source_func: Callable[[], T2]) -> CacheMemory["T2"]:
+            res = CacheMemory(source_func=source_func, expire=expire, logger=logger, name=name)
+            return res
+        return decorator
+
+
+class Cache[T]():  # This class helps to accelrate access to latest data coming from expensive function. The class has two flavours, memory-based and disk-based variants."""
+    def __init__(
+        self, source_func: Callable[[], T], expire: timedelta, logger: LoggerTemplate, path: Path, saver: Callable[[T, Path], Any] = to_pickle, reader: Callable[[Path], T] = from_pickle, name: Optional[str] = None
     ) -> None:
         self.cache: T
         self.source_func = source_func  # function which when called returns a fresh object to be frozen.
-        self.path: Optional[PathExtended] = PathExtended(path) if path is not None else None  # if path is passed, it will function as disk-based flavour.
+        self.path: PathExtended = PathExtended(path)
         self.time_produced = datetime.now()  # if path is None else
         self.save = saver
         self.reader = reader
@@ -173,28 +227,17 @@ class Cache(Generic[T]):  # This class helps to accelrate access to latest data
     @property
     def age(self):
         """Throws AttributeError if called before cache is populated and path doesn't exists"""
-        if self.path is None:  # memory-based cache.
-            return datetime.now() - self.time_produced
-        return datetime.now() - datetime.fromtimestamp(self.path.stat().st_mtime)
-
-    # def __setstate__(self, state: dict[str, Any]) -> None:
-    #     self.__dict__.update(state)
-    #     self.path = P.home() / self.path if self.path is not None else self.path
-    # def __getstate__(self) -> dict[str, Any]:
-    #     state = self.__dict__.copy()
-    #     state["path"] = self.path.rel2home() if self.path is not None else state["path"]
-    #     return state  # With this implementation, instances can be pickled and loaded up in different machine and still works.
+        return datetime.now() - self.time_produced
     def __call__(self, fresh: bool = False) -> T:
         self.last_call_is_fresh = False
         if fresh or not hasattr(self, "cache"):  # populate cache for the first time
-            if not fresh and self.path is not None and self.path.exists():
+            if not fresh and self.path.exists():
                 age = datetime.now() - datetime.fromtimestamp(self.path.stat().st_mtime)
                 msg1 = f"""
 📦 ════════════════════ CACHE OPERATION ════════════════════
 🔄 {self.name} cache: Reading cached values from `{self.path}`
 ⏱️  Lag = {age}
-════════════════════════════════════════════════════════════
-"""
+════════════════════════════════════════════════════════════"""
                 try:
                     self.cache = self.reader(self.path)
                 except Exception as ex:
@@ -203,8 +246,7 @@ class Cache(Generic[T]):  # This class helps to accelrate access to latest data
 ❌ ════════════════════ CACHE ERROR ════════════════════
 ⚠️  {self.name} cache: Cache file is corrupted
 🔍 Error: {ex}
-════════════════════════════════════════════════════════
-"""
+════════════════════════════════════════════════════════"""
                         self.logger.warning(msg1 + msg2)
                     self.cache = self.source_func()
                     self.last_call_is_fresh = True
@@ -221,13 +263,11 @@ class Cache(Generic[T]):  # This class helps to accelrate access to latest data
 🆕 ════════════════════ NEW CACHE ════════════════════
 🔄 {self.name} cache: Populating fresh cache from source func
 ℹ️  Reason: {why}
-════════════════════════════════════════════════════════
-""")
+════════════════════════════════════════════════════════""")
                 self.cache = self.source_func()  # fresh data.
                 self.last_call_is_fresh = True
                 self.time_produced = datetime.now()
-                if self.path is not None:
-                    self.save(self.cache, self.path)
+                self.save(self.cache, self.path)
         else:  # cache exists
             try:
                 age = self.age
@@ -243,8 +283,7 @@ class Cache(Generic[T]):  # This class helps to accelrate access to latest data
                 self.cache = self.source_func()
                 self.last_call_is_fresh = True
                 self.time_produced = datetime.now()
-                if self.path is not None:
-                    self.save(self.cache, self.path)
+                self.save(self.cache, self.path)
             else:
                 if self.logger:
                     self.logger.warning(f"""
@@ -256,28 +295,10 @@ class Cache(Generic[T]):  # This class helps to accelrate access to latest data
 
     @staticmethod
     def as_decorator(
-        expire: timedelta, logger: LoggerTemplate, path: Optional[Path] = None, saver: Callable[[T2, Path], Any] = to_pickle, reader: Callable[[Path], T2] = from_pickle, name: Optional[str] = None
+        expire: timedelta, logger: LoggerTemplate, path: Path, saver: Callable[[T2, Path], Any] = to_pickle, reader: Callable[[Path], T2] = from_pickle, name: Optional[str] = None
     ):  # -> Callable[..., 'Cache[T2]']:
         def decorator(source_func: Callable[[], T2]) -> Cache["T2"]:
             res = Cache(source_func=source_func, expire=expire, logger=logger, path=path, name=name, reader=reader, saver=saver)
             return res
 
         return decorator
-
-    def from_cloud(self, cloud: str, rel2home: bool = True, root: Optional[str] = None):
-        assert self.path is not None
-        exists = self.path.exists()
-        exists_but_old = exists and ((datetime.now() - datetime.fromtimestamp(self.path.stat().st_mtime)) > self.expire)
-        if not exists or exists_but_old:
-            returned_path = self.path.from_cloud(cloud=cloud, rel2home=rel2home, root=root)
-            if returned_path is None and not exists:
-                raise FileNotFoundError(f"❌ Failed to get @ {self.path}. Build the cache first with signed API.")
-            elif returned_path is None and exists:
-                self.logger.warning(f"""
-⚠️ ════════════════════ CLOUD FETCH WARNING ════════════════════
-🔄 Failed to get fresh data from cloud
-📦 Using old cache @ {self.path}
-════════════════════════════════════════════════════════════════""")
-        else:
-            pass  # maybe we don't need to fetch it from cloud, if its too hot
-        return self.reader(self.path)
